import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:factory_signage_app/const/config.dart';
import 'package:factory_signage_app/const/dimens.dart';
import 'package:factory_signage_app/const/string.dart';
import 'package:factory_signage_app/widget/progress_graph.dart';
import 'package:factory_signage_app/widget/progress_text.dart';
import 'package:factory_signage_app/widget/progress_title.dart';
import 'package:factory_signage_app/provider.dart';

class WeeklyGraph extends StatelessWidget {
  const WeeklyGraph(
      {super.key, this.size = const Size(double.infinity, double.infinity)});

  final Size size;

  @override
  Widget build(BuildContext context) {
    final Size widgetSize = MediaQuery.of(context).size;

    return SizedBox(
      width: size.width,
      height: size.height,
      child: Column(
        children: [
          ProgressTitle(
            weeklyGraphTitle,
            size: Size(
              double.infinity,
              progressTitleHeightRatio * widgetSize.height,
            ),
          ),
          Consumer(
            builder: (context, ref, _) => graph(ref, widgetSize),
          ),
          Consumer(
            builder: (context, ref, _) => text(ref, widgetSize),
          ),
        ],
      ),
    );
  }

  Widget graph(WidgetRef ref, Size widgetSize) {
    final dailyGraphData = ref.watch(dailyGraphDataProvider);
    final weeklyGraphData = dailyGraphData
        .map(
          (data) => (data / maxProduction * lineNames.length * 100).toInt(),
        )
        .toList();

    return ProgressGraph(
      weeklyGraphData,
      size: Size(
        double.infinity,
        progressGraphHeightRatio * widgetSize.height,
      ),
      maxY: weeklyGraphMaxY.toDouble(),
      interval: weeklyGraphInterval.toDouble(),
    );
  }

  Widget text(WidgetRef ref, Size widgetSize) {
    final dailyGraphData = ref.watch(dailyGraphDataProvider);
    final int weeklyGraphAverage =
        (dailyGraphData.reduce((value, element) => value + element) /
                maxProduction *
                100)
            .toInt();

    return ProgressText(
      statistics: weeklyGraphStatistics,
      number: weeklyGraphAverage.toString(),
      unit: weeklyGraphUnit,
      size: Size(
        double.infinity,
        progressTextHeightRatio * widgetSize.height,
      ),
    );
  }
}
